ifgen.plugins package — docs

Skip to main content
`Ctrl`+`K`

# ifgen.plugins package

## Subpackages

- ifgen.plugins.struct_receiver package
  - Module contents
    - `cpp_struct_receiver()`
    - `get_receiver_struct_names()`
    - `python_struct_receiver()`

## Module contents

An interface for optional code generation plugins.

ifgen.plugins.internal_plugin_entry(task: GenerateTask) → None

  A generator for a struct receiver interface.